{% block content %}

<div class="row">
	<div class="span12">
		<h3>Create an Account</h3>
		<form class="" action="/accounts/register" method="post">
		<ul class="unstyled">
		    {% raw form.as_p() %}
			<li>
            	<input class="btn btn-primary" type="submit" value="Create Account" />
			</li>
		</ul>
		</form>
	</div>
</div>
{% end %}
