{% block content %}

<div class="row">
	<div class="span12">
		<h3>Log in</h3>
	    <form class="" action="" method="post">
	    <ul class="unstyled">
            {% raw form.as_p() %}
	        <li>
	        	<input class="btn btn-primary" type="submit" value="Log in">
	    	</li>
            <li><a class="offset-by-one" href="/accounts/register">Create Account</a></li>
            <li><a class="" href="/accounts/recovery/">Forgot your password?</a></li>
		</ul>
	    </form>
	    </form>
	</div>
</div>
{% end %}
