<div class="navbar">
    <div class="navbar-inner">
        <div class="container">
            <ul class="nav">
                <li><a href="/" class="main">Home</a></li>
                <li><a href="/accounts/login">Log in</a></li>
                <li><a href="/accounts/register"><strong>Create Account</strong></a></li>
            </ul>
        </div>
    </div>
</div>