<div class="row">
    <div class="span12">
        <form class="" action="" method="post">
            {% raw form.as_p() %}
            <input class="btn btn-primary" type="submit" value="Next"/>
        </form>
    </div>
</div>